function [K,L] = glob( Ce, Ee, nze, Cn, En, nzn, ParEl, Nx, Ny, k0);

% builds matrix of global coefficients from simplex one

% nze, nzn = number of global non-zero edges and nodes
% Ce, Cn   = transformation matrix
% ParEl    = vector of parameters of finite elements
% Nx, Ny   = number of rectangular elements in resp. directions 


% matrices of simplex coefficients :
D1  = [  0  0  0;  0  1 -1;  0 -1  1];
D3  = [  1 -1  0; -1  1  0;  0  0  0];

tau = [  2  1  1;  1  2  1;  1  1  2];

Q1  = [  3 -1 -1; -1  1  1; -1  1  1];
Q3  = [  1  1 -1;  1  1 -1; -1 -1  3];

C1  = [  0 -2  2;  0  1 -1;  0  1 -1];
C3  = [  1 -1  0;  1 -1  0; -2  2  0];

St  = [  1  1  1;  1  1  1;  1  1  1] * 12;

L   = 2*3*Nx*Ny;	% number of local edges/nodes

zr1 = sparse(L,nze);
cce = zr1';
zr2 = sparse(L,nzn);
ccn = zr2';

for m=1:nze
  for n=1:Ce(1,m)
    hlp = 3*Ee(n,m) - 3 + abs( Ce(n+1,m));
    cce(m,hlp) = sign( Ce(n+1,m));
  end
end

for m=1:nzn
  for n=1:Cn(1,m)
    hlp = 3*En(n,m) - 3 + abs( Cn(n+1,m));
    ccn(m,hlp) = sign( Cn(n+1,m));
  end
end

A = sparse(nze,nze); B = A; C = A;
E = sparse(nzn,nze);

		% THROUGH ALL THE GLOBAL EDGES

Aa = zr1;		% [St] / mir
Bb = zr1;		% [Tt] * epr
Cc = zr1;		% [Tt] / mir
EE = zr1;		% [G]T / mir

for g=1:nze		% g-th column of product X.C

  for m=1:Ce(1,g)	% through all local edges in global one

    Tt = ParEl(5,Ee(m,g))*( ParEl(6,Ee(m,g))*Q1 + ParEl(7,Ee(m,g))*Q3);
    G  = 2*ParEl(5,Ee(m,g))*(ParEl(6,Ee(m,g))*C1 + ParEl(7,Ee(m,g))*C3);

    im = m + 1;

    for n=1:3
      hlp = 3*Ee(m,g) - 3 + n;
      if Ce(m+1,g)>0
        Aa(hlp,g) = St(n,Ce(im,g)) / ParEl(4,Ee(m,g));
        Bb(hlp,g) = Tt(n,Ce(im,g)) * ParEl(3,Ee(m,g));
        Cc(hlp,g) = Tt(n,Ce(im,g)) / ParEl(4,Ee(m,g));
        EE(hlp,g) = G (Ce(im,g),n) / ParEl(4,Ee(m,g));
      else
        xx = abs(Ce(im,g));
        Aa(hlp,g) = - St(n,xx) / ParEl(4,Ee(m,g));
        Bb(hlp,g) = - Tt(n,xx) * ParEl(3,Ee(m,g));
        Cc(hlp,g) = - Tt(n,xx) / ParEl(4,Ee(m,g));
        EE(hlp,g) = - G (xx,n) / ParEl(4,Ee(m,g));
      end
      
    end
     
  end

end

A = cce*Aa;
B = cce*Bb;
C = cce*Cc;
E = ccn*EE;


		% THROUGH ALL THE GLOBAL NODES

Dd = zr2;		% [G]  / mir
Ff = zr2;		% [Sz] / mir
Hh = zr2;		% [Tz] * epr

F = sparse(nzn,nzn); H = F;
D = sparse(nze,nzn);

for g=1:nzn		% g-th column of product X.C

  for m=1:Cn(1,g)	% through all local nodes in global one

    im = m + 1;
    G  = 2*ParEl(5,En(m,g))*(ParEl(6,En(m,g))*C1 + ParEl(7,En(m,g))*C3);
    Tz = ParEl(5,En(m,g))*ParEl(5,En(m,g))*tau;
    Sz = 6*ParEl(5,En(m,g))*(ParEl(6,En(m,g))*D1 + ParEl(7,En(m,g))*D3);

    for n=1:3
      hlp  = 3*En(m,g) - 3 + n;
      Dd(hlp,g) = G (n,Cn(im,g)) / ParEl(4,En(m,g));
      Ff(hlp,g) = Sz(n,Cn(im,g)) / ParEl(4,En(m,g));
      Hh(hlp,g) = Tz(n,Cn(im,g)) * ParEl(3,En(m,g));
    end
     
  end

end

D = cce*Dd;
F = ccn*Ff;
H = ccn*Hh;

clear Aa Bb Cc Dd EE Ff Hh;
clear cce ccn zr1 zr2;

zero1 = sparse(nze,nzn);
zero2 = sparse(nzn,nzn);

K = [ A-k0*B  zero1; zero1'  zero2];
L = [ C       D    ; E      F-k0*H];
